==> eam-wshub-proxyclient-11.6-2-sources.jar: net/datastream/schemas/mp_fields/CUSTOMERSURVEYANSWERID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour CUSTOMERSURVEYANSWERID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="CUSTOMERSURVEYANSWERID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SURVEYANSWERCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CUSTOMERSURVEYANSWERID_Type", propOrder = {
    "surveyanswercode",
    "description"
})
public class CUSTOMERSURVEYANSWERID_Type {

    @XmlElement(name = "SURVEYANSWERCODE", required = true)
    protected String surveyanswercode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Obtient la valeur de la propriété surveyanswercode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSURVEYANSWERCODE() {
        return surveyanswercode;
    }

    /**
     * Définit la valeur de la propriété surveyanswercode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSURVEYANSWERCODE(String value) {
        this.surveyanswercode = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/CUSTOMERSURVEYANSWERID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CUSTOMERSURVEYANSWERID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CUSTOMERSURVEYANSWERID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SURVEYANSWERCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CUSTOMERSURVEYANSWERID_Type", propOrder = {
    "surveyanswercode",
    "description"
})
public class CUSTOMERSURVEYANSWERID_Type {

    @XmlElement(name = "SURVEYANSWERCODE", required = true)
    protected String surveyanswercode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Gets the value of the surveyanswercode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSURVEYANSWERCODE() {
        return surveyanswercode;
    }

    /**
     * Sets the value of the surveyanswercode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSURVEYANSWERCODE(String value) {
        this.surveyanswercode = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}
